@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 from django.template import Library, Node, TemplateSyntaxError, Variable
 from django.utils.translation import ugettext as _
-from django.db.models import Sum
+from django.db.models import Sum, Model
 
 from visits.models import Visit
 
@@ -14,14 +15,20 @@ class VisitsNode(Node):
 
     def render(self, context):
         obj = self.obj.resolve(context)
-        context[self.context_var] = Visit.objects.filter(
+        
+        if isinstance(obj, dict):
+            context[self.context_var] = Visit.objects.filter(
+                uri=obj["request_path"],
+            ).aggregate(visits_sum=Sum("visits"))["visits_sum"]
+        elif isinstance(obj, Model):
+            context[self.context_var] = Visit.objects.filter(
+                object_app=obj._meta.app_label,
                 object_model=obj.__class__.__name__,
                 object_id=obj.id
-        ).aggregate(visits_sum=Sum('visits'))['visits_sum']
+            ).aggregate(visits_sum=Sum('visits'))['visits_sum']
         return ''
 
-
-def do_object_visits(parser, token):
+def do_get_visits(parser, token):
     """
     Retrive the number of visits of a model/slug
     """
@@ -36,4 +43,4 @@ def do_object_visits(parser, token):
         )
     return VisitsNode(bits[1], bits[3])
 
-register.tag('object_visits', do_object_visits)
+register.tag("get_visits", do_get_visits)
